============
About Vessim
============

Vessim is being developed at the research group for `Distributed and Operating
Systems (DOS) <https://www.dos.tu-berlin.de>`_ at TU Berlin.
Development is funded by the `Federal Ministry of Education and Research (BMBF) <https://www.bmbf.de/>`_ as part of the Software Campus project `SYNERGY <https://softwarecampus.de/en/projekt/synergy-synergies-of-distributed-artificial-intelligence-and-renewable-energy-generation/>`_ under the lead of `Philipp Wiesner <https://philippwiesner.org>`_.

After researching on energy-aware and carbon-aware computing systems for several years, we noticed how almost all scientific evaluations are simulation-based, as (globally distributed) hardware testbeds are rare and expensive to build and maintain.
Vessim tries to simplify and unify such evaluations and enables the continuous testing of new applications.
Active development of Vessim started in March 2023.

Many thanks to our team which worked on Vessim for more than a year now:

- Marvin Steinke
- Paul Kilian
- Amanda Malkowski

In case of questions, please reach out to `Philipp Wiesner
<https://philippwiesner.org>`_.


Publications
============


If you use Vessim in your research, please cite our paper:

    Philipp Wiesner, Ilja Behnke, Paul Kilian, Marvin Steinke, and Odej Kao. "`Vessim: A Testbed for Carbon-Aware Applications and Systems. <https://arxiv.org/pdf/2306.09774.pdf>`_" 3rd Workshop on Sustainable Computer Systems (HotCarbon). 2024.

.. raw:: html

   <details>
   <summary><a>Bibtex</a></summary>

.. code-block:: text

    @inproceedings{wiesner2024vessim,
        title     = {Vessim: A Testbed for Carbon-Aware Applications and Systems},
        author    = {Wiesner, Philipp and Behnke, Ilja and Kilian, Paul and Steinke, Marvin and Kao, Odej},
        booktitle = {3rd Workshop on Sustainable Computer Systems (HotCarbon)},
        year      = {2024},
    }

.. raw:: html

   </details><br>


For details in Vessim's software-in-the-loop simulation methodology, refer to our journal paper:

    Philipp Wiesner, Marvin Steinke, Henrik Nickel, Yazan Kitana, and Odej Kao. "`Software-in-the-Loop Simulation for Developing and Testing Carbon-Aware Applications <https://onlinelibrary.wiley.com/doi/10.1002/spe.3275>`_" Software: Practice and Experience, 53 (12). 2023.

.. raw:: html

   <details>
   <summary><a>Bibtex</a></summary>

.. code-block:: text

    @article{wiesner2023sil,
        author    = {Wiesner, Philipp and Steinke, Marvin and Nickel, Henrik and Kitana, Yazan and Kao, Odej},
        title     = {Software-in-the-loop simulation for developing and testing carbon-aware applications},
        journal   = {Software: Practice and Experience},
        year      = {2023},
        volume    = {53},
        number    = {12},
        pages     = {2362-2376},
        doi       = {https://doi.org/10.1002/spe.3275}
    }

.. raw:: html

   </details>


Publications using Vessim
=========================

- Paul Kilian, Philipp Wiesner, and Odej Kao. "`Choosing the Right Battery Model for Data Center Simulations <https://arxiv.org/pdf/2506.17739>`_". 1st International Workshop on Low Carbon Computing (LOCO). 2024.
- Philipp Wiesner, Ramin Khalili, Dennis Grinwald, Pratik Agrawal, Lauritz Thamsen, and Odej Kao. "`FedZero: Leveraging Renewable Excess Energy in Federated Learning <https://dl.acm.org/doi/10.1145/3632775.3639589>`_". 15th ACM International Conference on Future and Sustainable Energy Systems (e-Energy). 2024.



License
=======

Vessim is released under the `MIT License
<https://github.com/dos-group/vessim/blob/main/LICENSE>`_. 
